==> poedit_1.2.5.orig.tar.gz: poedit-1.2.5/src/resources/xrc_strings.h <==
_("About poEdit");
_("OK");
_("Edit comment");
_("Comment:");
_("OK");
_("Cancel");
_("Clear");
_("Clear the comment");
_("Edit the file in text editor");
_("Find...");
_("String to find:");
_("Case sensitive");
_("Find in original strings");
_("Find in translations");
_("Cancel");
_("< Previous");
_("Next >");
_("Create new translations project");
_("Edit the project");
_("Delete the project");
_("Update all catalogs in the project");
_("Edit project");
_("Project name:");
_("Browse");
_("Add directory to the list");
_("OK");
_("Cancel");
_("&File");
_("Catalogs &manager");
_("&New catalog...");
_("&Open");
_("&Save");
_("Save &as...");
_("E&xport...");
_("&Preferences...");
_("&Close");
_("&Edit");
_("Copy original to translation field");
_("&Show references");
_("&Find...");
_("Translation is &fuzzy");
_("Edit &comment");
_("&Catalog");
_("&Update from sources");
_("Update from &POT file...");
_("&Automatically translate using TM");
_("&Settings...");
_("&View");
_("&Fullscreen view");
_("Display &quotes");
_("Display &line numbers");
_("Show &comment window");
_("&Shaded translations list");
_("&Contents...");
_("GNU gettext documentation");
_("&About...");
_("&Help");
_("Preferences");
_("Personalize");
_("Identity");
_("Your name:");
_("Your e-mail address:");
_("Change UI language");
_("Editor");
_("Behavior");
_("Automatically compile .mo file on save");
_("Show summary after catalog update");
_("Open catalogs manager on poEdit startup");
_("Always change focus to text input field");
_("Never let the list of strings take focus. If enabled, you must use Ctrl-arrows for keyboard navigation but you can also type text immediately, without having to press Tab to change focus.");
_("Comment window is editable");
_("If checked, the comment window will be editable.");
_("CR/LF conversion");
_("Line endings format:");
_("Unix");
_("Windows");
_("Macintosh");
_("current platform's default");
_("Don't change format of existing catalogs");
_("External editor");
_("Editor executable:");
_("(%f will be substituted with filename, %l with line number)");
_("Open source files in editor, not in file viewer");
_("Fonts");
_("Use custom font for translations list");
_("Choose");
_("Use custom font for text fields");
_("Choose");
_("Translation Memory");
_("Database");
_("Path to DB:");
_("Browse");
_("Add");
_("Pick language from the list of known languages");
_("Generate database");
_("Regenerate translation memory from catalogs in paths listed above.");
_("Configuration");
_("Max. # of missing words:");
_("Max. difference in sentence length:");
_("Automatically translate when updating catalog");
_("Parsers");
_("Source code parsers:");
_("New");
_("Edit");
_("Delete");
_("OK");
_("Cancel");
_("Parser setup");
_("Language:");
_("Language:");
_("List of extensions separated by semicolons (e.g. *.cpp;*.h):");
_("Invocation:");
_("Parser command:");
_("This is the command used to launch the parser.\n%o expands to the name of output file, %K to list\nof keywords, %F to list of input files,\n%C to charset flag (see below).");
_("An item in keywords list:");
_("This will be attached to the command line once\nfor each keyword. %k expands to the keyword.");
_("An item in input files list:");
_("This will be attached to the command line once\nfor each input file. %f expands to the filename.");
_("Source code charset:");
_("This will be attached to the command line\nonly if source codecharset was given. %c expands to charset value.");
_("OK");
_("Cancel");
_("Browse");
_("Add path to the list of directories where catalogs lie.");
_("Proceed");
_("Cancel");
_("Generate TM database");
_("Cancel");
_("Settings");
_("Project name and version:");
_("Team:");
_("Team's email address:");
_("Language:");
_("Country:");
_("Charset:");
_("Source code charset:");
_("Project info");
_("Base path:");
_("Paths");
_("Use these keywords (function names) to recognize translatable strings\nin source files, in addition to default ones.");
_("Keywords");
_("OK");
_("Cancel");
_("Update summary");
_("These strings were found in the sources but were not in the catalog.\npoEdit will add them to the catalog now.");
_("New strings");
_("These strings are no longer in the sources.\npoEdit will remove them from the catalog now.");
_("Obsolete strings");
_("(0 new, 0 obsolete)");
_("OK");
_("Undo");
_("Update translation memory");
_("Please add directories where locale files are stored on your system:");
_("Browse");
_("Reset to defaults");
_("Translation memory will be built from the files listed below.\nYou can add more files to the list now.");
_("Add files");
_("Open catalog");
_("Save catalog");
_("Update catalog - synchronize it with sources");
_("Display quotes around the string?");
_("Toggled if selected string has fuzzy translation");
_("Edit comment");
_("Fullscreen view");
_("Help");

==> poedit_1.3.1.orig.tar.gz: poedit-1.3.1/src/resources/xrc_strings.h <==
_("About poEdit");
_("OK");
_("Edit comment");
_("Comment:");
_("OK");
_("Cancel");
_("Clear");
_("Clear the comment");
_("Edit the file in text editor");
_("Find...");
_("String to find:");
_("Case sensitive");
_("Find in original strings");
_("Find in translations");
_("Cancel");
_("< Previous");
_("Next >");
_("Create new translations project");
_("Edit the project");
_("Delete the project");
_("Update all catalogs in the project");
_("Edit project");
_("Project name:");
_("Browse");
_("Add directory to the list");
_("OK");
_("Cancel");
_("&File");
_("&Preferences...");
_("&Close");
_("&File");
_("Catalogs &manager");
_("&New catalog...");
_("&Open");
_("&Save");
_("Save &as...");
_("E&xport...");
_("&Preferences...");
_("&Close");
_("&Edit");
_("Copy original to translation field");
_("&Show references");
_("&Find...");
_("Translation is &fuzzy");
_("Edit &comment");
_("C&atalog");
_("&Update from sources");
_("Update from &POT file...");
_("&Automatically translate using TM");
_("&Settings...");
_("&View");
_("&Fullscreen view");
_("Display &quotes");
_("Display &line numbers");
_("Show &comment window");
_("&Shaded translations list");
_("&Contents...");
_("GNU gettext documentation");
_("&About...");
_("&Help");
_("Preferences");
_("Personalize");
_("Identity");
_("Your name:");
_("Your e-mail address:");
_("Change UI language");
_("Editor");
_("Behavior");
_("Automatically compile .mo file on save");
_("Show summary after catalog update");
_("Open catalogs manager on poEdit startup");
_("Always change focus to text input field");
_("Never let the list of strings take focus. If enabled, you must use Ctrl-arrows for keyboard navigation but you can also type text immediately, without having to press Tab to change focus.");
_("Comment window is editable");
_("If checked, the comment window will be editable.");
_("Automatic spellchecking");
_("Enables on-the-fly spellchecking");
_("CR/LF conversion");
_("Line endings format:");
_("Unix");
_("Windows");
_("Macintosh");
_("current platform's default");
_("Don't change format of existing catalogs");
_("External editor");
_("Editor executable:");
_("(%f will be substituted with filename, %l with line number)");
_("Open source files in editor, not in file viewer");
_("Fonts");
_("Use custom font for translations list");
_("Choose");
_("Use custom font for text fields");
_("Choose");
_("Translation Memory");
_("Database");
_("Path to DB:");
_("Browse");
_("Add");
_("Pick language from the list of known languages");
_("Generate database");
_("Regenerate translation memory from catalogs in paths listed above.");
_("Configuration");
_("Max. # of missing words:");
_("Max. difference in sentence length:");
_("Automatically translate when updating catalog");
_("Parsers");
_("Source code parsers:");
_("New");
_("Edit");
_("Delete");
_("OK");
_("Cancel");
_("Parser setup");
_("Language:");
_("Language:");
_("List of extensions separated by semicolons (e.g. *.cpp;*.h):");
_("Invocation:");
_("Parser command:");
_("This is the command used to launch the parser.\n%o expands to the name of output file, %K to list\nof keywords, %F to list of input files,\n%C to charset flag (see below).");
_("An item in keywords list:");
_("This will be attached to the command line once\nfor each keyword. %k expands to the keyword.");
_("An item in input files list:");
_("This will be attached to the command line once\nfor each input file. %f expands to the filename.");
_("Source code charset:");
_("This will be attached to the command line\nonly if source codecharset was given. %c expands to charset value.");
_("OK");
_("Cancel");
_("Browse");
_("Add path to the list of directories where catalogs lie.");
_("Proceed");
_("Cancel");
_("Generate TM database");
_("Cancel");
_("Settings");
_("Project name and version:");
_("Team:");
_("Team's email address:");
_("Language:");
_("Country:");
_("Charset:");
_("Source code charset:");
_("Plural Forms:");
_("Project info");
_("Base path:");
_("Paths");
_("Use these keywords (function names) to recognize translatable strings\nin source files, in addition to default ones.");
_("Keywords");
_("OK");
_("Cancel");
_("Update summary");
_("These strings were found in the sources but were not in the catalog.\npoEdit will add them to the catalog now.");
_("New strings");
_("These strings are no longer in the sources.\npoEdit will remove them from the catalog now.");
_("Obsolete strings");
_("(0 new, 0 obsolete)");
_("OK");
_("Undo");
_("Update translation memory");
_("Please add directories where locale files are stored on your system:");
_("Browse");
_("Reset to defaults");
_("Translation memory will be built from the files listed below.\nYou can add more files to the list now.");
_("Add files");
_("Open catalog");
_("Save catalog");
_("Update catalog - synchronize it with sources");
_("Display quotes around the string?");
_("Toggled if selected string has fuzzy translation");
_("Edit comment");
_("Fullscreen view");
_("Help");
